@@ -61,9 +61,10 @@ def get_frequency(df):
     for index, row in df.iterrows():
         arreglo=row["keywords"].split(",")
         arreglo.pop()
+        arreglo=list(dict.fromkeys(arreglo))#elimina los duplicados para contar una vez por noticia cada palabra
         concept_freq = Counter(arreglo)
         concept_freq_total = concept_freq_total + concept_freq
-    return {"total_elements": sum(concept_freq_total.values()), "dictionary": concept_freq_total}
+    return {"total_news":len(df),"total_elements": sum(concept_freq_total.values()), "dictionary": concept_freq_total}
 
 def group_by_date(dataset, granularity="month"):
     if granularity == "month":
@@ -128,4 +129,32 @@ def get_n_most_freq(freq_struct, n, graph=False):
         plt.title("term frequency top %i words" %(n))
     return dict_orders[:n]
 
+def freq(word_distribution,top_n=None, words=None, graph=True):
+    concept_freq_total=Counter({})
+    total_news=0
+    for a in word_distribution:
+        concept_freq_total= concept_freq_total + word_distribution[a]["dictionary"]
+        total_news=total_news+word_distribution["total_news"]
+    if top_n==None and words ==None:
+        print("debes pasar como argumento top_n o un arreglo words")
+    elif top_n!=None and words !=None:
+        print("debes pasar como argumento top_n o un arreglo words, no ambos")
+    elif top_n!=None:
+        top=concept_freq_total.most_common(3)
+        if graph:
+        
+            x = [x[0] for x in top]
+            y = [x[1]/total_news for x in top]
+            plt.bar(x,y)
+            plt.title("term frecuency top %i words" %(top_n))
+        return top
+    elif words!=None:
+        y = []
+        for word in words:
+            y.append(concept_freq_total[word]/total_news)
+        plt.bar(words,y)
+        plt.tittle("term frecuency bar graph")
+        
+        
+
 
